==> IBrokers_0.2-2.tar.gz: IBrokers/R/twsTickType.R <==
`.twsTickType` <-
structure(list( 
     BID_SIZE   = 0,
     BID        = 1,
     ASK        = 2,
     ASK_SIZE   = 3,
     LAST       = 4,
     LAST_SIZE  = 5,
     HIGH       = 6,
     LOW        = 7,
     VOLUME     = 8,
     CLOSE      = 9,
     BID_OPTION = 10,
     ASK_OPTION = 11,
     LAST_OPTION = 12,
     MODEL_OPTION = 13,
     OPEN         = 14,
     LOW_13_WEEK  = 15,
     HIGH_13_WEEK = 16,
     LOW_26_WEEK  = 17,
     HIGH_26_WEEK = 18,
     LOW_52_WEEK  = 19,
     HIGH_52_WEEK = 20,
     AVG_VOLUME   = 21,
     OPEN_INTEREST = 22,
     OPTION_HISTORICAL_VOL = 23,
     OPTION_IMPLIED_VOL = 24,
     OPTION_BID_EXCH = 25,
     OPTION_ASK_EXCH = 26,
     OPTION_CALL_OPEN_INTEREST = 27,
     OPTION_PUT_OPEN_INTEREST = 28,
     OPTION_CALL_VOLUME = 29,
     OPTION_PUT_VOLUME = 30,
     INDEX_FUTURE_PREMIUM = 31,
     BID_EXCH = 32,
     ASK_EXCH = 33,
     AUCTION_VOLUME = 34,
     AUCTION_PRICE = 35,
     AUCTION_IMBALANCE = 36,
     MARK_PRICE = 37,
     BID_EFP_COMPUTATION  = 38,
     ASK_EFP_COMPUTATION  = 39,
     LAST_EFP_COMPUTATION = 40,
     OPEN_EFP_COMPUTATION = 41,
     HIGH_EFP_COMPUTATION = 42,
     LOW_EFP_COMPUTATION = 43,
     CLOSE_EFP_COMPUTATION = 44,
     LAST_TIMESTAMP = 45,
     SHORTABLE = 46),
 .Names=c( "BID_SIZE","BID","ASK","ASK_SIZE","LAST","LAST_SIZE",
"HIGH","LOW","VOLUME","CLOSE","BID_OPTION",
"ASK_OPTION","LAST_OPTION","MODEL_OPTION","OPEN","LOW_13_WEEK",
"HIGH_13_WEEK","LOW_26_WEEK","HIGH_26_WEEK","LOW_52_WEEK","HIGH_52_WEEK","AVG_VOLUME",
"OPEN_INTEREST","OPTION_HISTORICAL_VOL",
"OPTION_IMPLIED_VOL","OPTION_BID_EXCH","OPTION_ASK_EXCH",
"OPTION_CALL_OPEN_INTEREST","OPTION_PUT_OPEN_INTEREST",
"OPTION_CALL_VOLUME","OPTION_PUT_VOLUME","INDEX_FUTURE_PREMIUM",
"BID_EXCH","ASK_EXCH","AUCTION_VOLUME","AUCTION_PRICE",
"AUCTION_IMBALANCE","MARK_PRICE","BID_EFP_COMPUTATION","ASK_EFP_COMPUTATION",
"LAST_EFP_COMPUTATION","OPEN_EFP_COMPUTATION","HIGH_EFP_COMPUTATION","LOW_EFP_COMPUTATION",
"CLOSE_EFP_COMPUTATION","LAST_TIMESTAMP","SHORTABLE"))

==> IBrokers_0.2-4.tar.gz: IBrokers/R/twsTickType.R <==
`.twsTickType` <-
structure(list( 
     BID_SIZE   = 0,
     BID        = 1,
     ASK        = 2,
     ASK_SIZE   = 3,
     LAST       = 4,
     LAST_SIZE  = 5,
     HIGH       = 6,
     LOW        = 7,
     VOLUME     = 8,
     CLOSE      = 9,
     BID_OPTION = 10,
     ASK_OPTION = 11,
     LAST_OPTION = 12,
     MODEL_OPTION = 13,
     OPEN         = 14,
     LOW_13_WEEK  = 15,
     HIGH_13_WEEK = 16,
     LOW_26_WEEK  = 17,
     HIGH_26_WEEK = 18,
     LOW_52_WEEK  = 19,
     HIGH_52_WEEK = 20,
     AVG_VOLUME   = 21,
     OPEN_INTEREST = 22,
     OPTION_HISTORICAL_VOL = 23,
     OPTION_IMPLIED_VOL = 24,
     OPTION_BID_EXCH = 25,
     OPTION_ASK_EXCH = 26,
     OPTION_CALL_OPEN_INTEREST = 27,
     OPTION_PUT_OPEN_INTEREST = 28,
     OPTION_CALL_VOLUME = 29,
     OPTION_PUT_VOLUME = 30,
     INDEX_FUTURE_PREMIUM = 31,
     BID_EXCH = 32,
     ASK_EXCH = 33,
     AUCTION_VOLUME = 34,
     AUCTION_PRICE = 35,
     AUCTION_IMBALANCE = 36,
     MARK_PRICE = 37,
     BID_EFP_COMPUTATION  = 38,
     ASK_EFP_COMPUTATION  = 39,
     LAST_EFP_COMPUTATION = 40,
     OPEN_EFP_COMPUTATION = 41,
     HIGH_EFP_COMPUTATION = 42,
     LOW_EFP_COMPUTATION = 43,
     CLOSE_EFP_COMPUTATION = 44,
     LAST_TIMESTAMP = 45,
     SHORTABLE = 46,
     FUNDAMENTAL_RATIOS = 47,
     RT_VOLUME = 48),
 .Names=c( "BID_SIZE","BID","ASK","ASK_SIZE","LAST","LAST_SIZE",
"HIGH","LOW","VOLUME","CLOSE","BID_OPTION",
"ASK_OPTION","LAST_OPTION","MODEL_OPTION","OPEN","LOW_13_WEEK",
"HIGH_13_WEEK","LOW_26_WEEK","HIGH_26_WEEK","LOW_52_WEEK","HIGH_52_WEEK","AVG_VOLUME",
"OPEN_INTEREST","OPTION_HISTORICAL_VOL",
"OPTION_IMPLIED_VOL","OPTION_BID_EXCH","OPTION_ASK_EXCH",
"OPTION_CALL_OPEN_INTEREST","OPTION_PUT_OPEN_INTEREST",
"OPTION_CALL_VOLUME","OPTION_PUT_VOLUME","INDEX_FUTURE_PREMIUM",
"BID_EXCH","ASK_EXCH","AUCTION_VOLUME","AUCTION_PRICE",
"AUCTION_IMBALANCE","MARK_PRICE","BID_EFP_COMPUTATION","ASK_EFP_COMPUTATION",
"LAST_EFP_COMPUTATION","OPEN_EFP_COMPUTATION","HIGH_EFP_COMPUTATION","LOW_EFP_COMPUTATION",
"CLOSE_EFP_COMPUTATION","LAST_TIMESTAMP","SHORTABLE","FUNDAMENTAL_RATIOS","RT_VOLUME"))
